@@ -25,7 +25,7 @@ from ...models.agent import Agent, AgentCapability, AgentStatus
 from ...utils.exceptions import AgentError, MAOSError
 from ..formatters import OutputFormatter, TableFormatter
 from ..monitoring import AgentMonitor
-from ..main import _orchestrator, init_orchestrator
+from .._main import _orchestrator, init_orchestrator
 
 console = Console()
 agent_app = typer.Typer(help="🤖 Agent lifecycle operations")
