@@ -22,7 +22,7 @@ from rich.tree import Tree
 
 from ..formatters import OutputFormatter, format_status, format_duration, format_size, create_summary_panel
 from ..monitoring import SystemMonitor
-from ..main import _orchestrator, init_orchestrator
+from .._main import _orchestrator, init_orchestrator
 
 console = Console()
 status_app = typer.Typer(help="📊 System monitoring and status")
