@@ -27,7 +27,7 @@ from ...models.task import Task, TaskStatus, TaskPriority
 from ...utils.exceptions import TaskError, MAOSError
 from ..formatters import OutputFormatter, TableFormatter, JSONFormatter
 from ..monitoring import TaskMonitor
-from ..main import _orchestrator, init_orchestrator
+from .._main import _orchestrator, init_orchestrator
 
 console = Console()
 task_app = typer.Typer(help="📋 Task management operations")
